      SUBROUTINE inifis(ngrid,nlayer,nq,
     $           day_ini,pdaysec,ptimestep,
     $           plat,plon,parea,
     $           prad,pg,pr,pcpp)

      use radinc_h, only : naerkind
      use datafile_mod, only: datadir
      use comdiurn_h, only: sinlat, coslat, sinlon, coslon
      use comgeomfi_h, only: long, lati, area, totarea, totarea_planet
      use comsoil_h, only: ini_comsoil_h
      use control_mod, only: ecritphy
      use planete_mod, only: nres
      use planetwide_mod, only: planetwide_sumval

!=======================================================================
!
!   purpose:
!   -------
!
!   Initialisation for the physical parametrisations of the LMD 
!   Generic Model.
!
!   author: Frederic Hourdin 15 / 10 /93
!   -------
!   modified: Sebastien Lebonnois 11/06/2003 (new callphys.def)
!             Ehouarn Millour (oct. 2008) tracers are now identified
!              by their names and may not be contiguously
!              stored in the q(:,:,:,:) array
!             E.M. (june 2009) use getin routine to load parameters
!
!
!   arguments:
!   ----------
!
!   input:
!   ------
!
!    ngrid                 Size of the horizontal grid.
!                          All internal loops are performed on that grid.
!    nlayer                Number of vertical layers.
!    pdayref               Day of reference for the simulation
!    pday                  Number of days counted from the North. Spring
!                          equinoxe.
!
!=======================================================================
!
!-----------------------------------------------------------------------
!   declarations:
!   -------------
      use datafile_mod, only: datadir
! to use  'getin'
!      USE ioipsl_getincom 
      USE ioipsl_getincom_p
      use mod_phys_lmdz_para, only : is_master
      IMPLICIT NONE
!#include "dimensions.h"
!#include "dimphys.h"
!#include "planete.h"
#include "comcstfi.h"
#include "callkeys.h"



      REAL,INTENT(IN) :: prad,pg,pr,pcpp,pdaysec,ptimestep
 
      INTEGER,INTENT(IN) :: ngrid,nlayer,nq
      REAL,INTENT(IN) :: plat(ngrid),plon(ngrid),parea(ngrid)
      integer day_ini
      INTEGER ig,ierr
 
      EXTERNAL iniorbit,orbite
      EXTERNAL SSUM
      REAL SSUM
 
      CHARACTER ch1*12
      CHARACTER ch80*80

      logical chem, h2o
      logical :: parameter, doubleq=.false.

      real psurf,pN2 ! added by RW for Gliese 581d N2+CO2

!$OMP MASTER
      rad=prad
      daysec=pdaysec
      dtphys=ptimestep
      cpp=pcpp
      g=pg
      r=pr
      rcp=r/cpp
      ! Ehouarn debug:
      if (is_master) then
      write(*,*) "inifis: rad=",rad
      write(*,*) "        daysec=",daysec
      write(*,*) "        dtphys=",dtphys
      write(*,*) "        cpp=",cpp
      write(*,*) "        g=",g
      write(*,*) "        r=",r
      write(*,*) "        rcp=",rcp
      end if

      avocado = 6.02214179e23   ! added by RW

!$OMP END MASTER
!$OMP BARRIER

      ! read in 'ecritphy' (frequency of calls to physics, in dynamical steps)
      ! (also done in dyn3d/defrun_new but not in LMDZ.COMMON)
      call getin_p("ecritphy",ecritphy)

! --------------------------------------------------------------
!  Reading the "callphys.def" file controlling some key options
! --------------------------------------------------------------
     
!$OMP MASTER     
      ! check that 'callphys.def' file is around
      OPEN(99,file='callphys.def',status='old',form='formatted'
     &     ,iostat=ierr)
      CLOSE(99)
      IF(ierr.EQ.0) iscallphys=.true. !iscallphys initialised as false in callkeys.h
!$OMP END MASTER
!$OMP BARRIER
      
!!!      IF(ierr.EQ.0) THEN
      IF(iscallphys) THEN
         if (is_master) then
         PRINT*
         PRINT*
         PRINT*,'--------------------------------------------'
         PRINT*,' inifis: Parametres pour la physique (callphys.def)'
         PRINT*,'--------------------------------------------'
         end if

         if (is_master) write(*,*) "Directory where external input",
     &		" files are:"

         ! default 'datadir' is set in "datadir_mod"
         call getin_p("datadir",datadir) ! default path
         if (is_master) write(*,*) " datadir = ",trim(datadir)

         if (is_master) write(*,*) "Run with or without tracer",
     &		" transport ?"
         tracer=.false. ! default value
         call getin_p("tracer",tracer)
         if (is_master) write(*,*) " tracer = ",tracer

         if (is_master) write(*,*) "Run with or without atm mass",
     &		" update due to tracer evaporation/condensation?"
         mass_redistrib=.false. ! default value
         call getin_p("mass_redistrib",mass_redistrib)
         if (is_master) write(*,*) " mass_redistrib = ",mass_redistrib

         if (is_master) write(*,*) "Diurnal cycle ?"
         if (is_master) write(*,*) "(if diurnal=false, diurnal",
     &		" averaged solar heating)"
         diurnal=.true. ! default value
         call getin_p("diurnal",diurnal)
         if (is_master) write(*,*) " diurnal = ",diurnal

         if (is_master) write(*,*) "Seasonal cycle ?"
         if (is_master) write(*,*) "(if season=false, Ls stays",
     &		" constant, to value set in 'start'"
         season=.true. ! default value
         call getin_p("season",season)
         if (is_master) write(*,*) " season = ",season

         if (is_master) write(*,*) "Tidally resonant rotation ?"
         tlocked=.false. ! default value
         call getin_p("tlocked",tlocked)
         if (is_master) write(*,*) "tlocked = ",tlocked

         if (is_master) write(*,*) "Saturn ring shadowing ?"
         rings_shadow = .false.
         call getin_p("rings_shadow", rings_shadow)
         if (is_master) write(*,*) "rings_shadow = ", rings_shadow
         
         if (is_master) write(*,*) "Compute latitude-dependent",
     &		" gravity field?"
         oblate = .false.
         call getin_p("oblate", oblate)
         if (is_master) write(*,*) "oblate = ", oblate

         if (is_master) write(*,*) "Flattening of the planet (a-b)/a "
         flatten = 0.0
         call getin_p("flatten", flatten)
         if (is_master) write(*,*) "flatten = ", flatten
         

         if (is_master) write(*,*) "Needed if oblate=.true.: J2"
         J2 = 0.0
         call getin_p("J2", J2)
         if (is_master) write(*,*) "J2 = ", J2
         
         if (is_master) write(*,*) "Needed if oblate=.true.: Planet",
     &		" mass (*1e24 kg)"
         MassPlanet = 0.0
         call getin_p("MassPlanet", MassPlanet)
         if (is_master) write(*,*) "MassPlanet = ", MassPlanet         

         if (is_master) write(*,*) "Needed if oblate=.true.: Planet",
     &		" mean radius (m)"
         Rmean = 0.0
         call getin_p("Rmean", Rmean)
         if (is_master) write(*,*) "Rmean = ", Rmean
         
         if (is_master) write(*,*) 
     &      "Add sponge after radiative transfer?"
         callradsponge=.false.
         call getin_p("callradsponge", callradsponge)
         if (is_master) write(*,*) "callradsponge = ", callradsponge

! Test of incompatibility:
! if tlocked, then diurnal should be false
         if (tlocked.and.diurnal) then
           if (is_master) print*,'If diurnal=true, we should turn off',
     &		' tlocked.'
           stop
         endif

         if (is_master) write(*,*) "Tidal resonance ratio ?"
         nres=0          ! default value
         call getin_p("nres",nres)
         if (is_master) write(*,*) "nres = ",nres

         if (is_master) write(*,*) "Write some extra output to the",
     &		" screen ?"
         lwrite=.false. ! default value
         call getin_p("lwrite",lwrite)
         if (is_master) write(*,*) " lwrite = ",lwrite

         if (is_master) write(*,*) "Save statistics in file stats.nc ?"
         callstats=.true. ! default value
         call getin_p("callstats",callstats)
         if (is_master) write(*,*) " callstats = ",callstats

         if (is_master) write(*,*) "Test energy conservation of model",
     &		" physics ?"
         enertest=.false. ! default value
         call getin_p("enertest",enertest)
         if (is_master) write(*,*) " enertest = ",enertest

         if (is_master) write(*,*) "Check to see if cpp values used",
     &		" match gases.def ?"
         check_cpp_match=.true. ! default value
         call getin_p("check_cpp_match",check_cpp_match)
         if (is_master) write(*,*) " check_cpp_match = ",check_cpp_match

         if (is_master) write(*,*) "call radiative transfer ?"
         callrad=.true. ! default value
         call getin_p("callrad",callrad)
         if (is_master) write(*,*) " callrad = ",callrad

         if (is_master) write(*,*) "call correlated-k radiative",
     &		" transfer ?"
         corrk=.true. ! default value
         call getin_p("corrk",corrk)
         if (is_master) write(*,*) " corrk = ",corrk

         if (is_master) write(*,*) "prohibit calculations outside",
     &		" corrk T grid?"
         strictboundcorrk=.true. ! default value
         call getin_p("strictboundcorrk",strictboundcorrk)
         if (is_master) write(*,*) "strictboundcorrk = ",
     &		strictboundcorrk

         if (is_master) write(*,*) "call gaseous absorption in the",
     &		" visible bands? (matters only if callrad=T)"
         callgasvis=.false. ! default value
         call getin_p("callgasvis",callgasvis)
         if (is_master) write(*,*) " callgasvis = ",callgasvis
        
         if (is_master) write(*,*) "call continuum opacities in",
     &		" radiative transfer ? (matters only if callrad=T)"
         continuum=.true. ! default value
         call getin_p("continuum",continuum)
         if (is_master) write(*,*) " continuum = ",continuum

         if (is_master) write(*,*) "use analytic function for H2O",
     &		" continuum ?"
         H2Ocont_simple=.false. ! default value
         call getin_p("H2Ocont_simple",H2Ocont_simple)
         if (is_master) write(*,*) " H2Ocont_simple = ",H2Ocont_simple
 
         if (is_master) write(*,*) "call turbulent vertical",
     &		" diffusion ?"
         calldifv=.true. ! default value
         call getin_p("calldifv",calldifv)
         if (is_master) write(*,*) " calldifv = ",calldifv

         if (is_master) write(*,*) "use turbdiff instead of vdifc ?"
         UseTurbDiff=.true. ! default value
         call getin_p("UseTurbDiff",UseTurbDiff)
         if (is_master) write(*,*) " UseTurbDiff = ",UseTurbDiff

         if (is_master) write(*,*) "call convective adjustment ?"
         calladj=.true. ! default value
         call getin_p("calladj",calladj)
         if (is_master) write(*,*) " calladj = ",calladj

         if (is_master) write(*,*) "call CO2 condensation ?"
         co2cond=.false. ! default value
         call getin_p("co2cond",co2cond)
         if (is_master) write(*,*) " co2cond = ",co2cond
! Test of incompatibility
         if (co2cond.and.(.not.tracer)) then
            if (is_master) print*,'We need a CO2 ice tracer to',
     &		' condense CO2'
            call abort
         endif 
 
         if (is_master) write(*,*) "CO2 supersaturation level ?"
         co2supsat=1.0 ! default value
         call getin_p("co2supsat",co2supsat)
         if (is_master) write(*,*) " co2supsat = ",co2supsat

         if (is_master) write(*,*) "Radiative timescale for Newtonian",
     &		" cooling ?"
         tau_relax=30. ! default value
         call getin_p("tau_relax",tau_relax)
         if (is_master) write(*,*) " tau_relax = ",tau_relax
         tau_relax=tau_relax*24*3600 ! convert Earth days --> seconds

         if (is_master) write(*,*)"call thermal conduction in",
     &		" the soil ?"
         callsoil=.true. ! default value
         call getin_p("callsoil",callsoil)
         if (is_master) write(*,*) " callsoil = ",callsoil
         
         if (is_master) write(*,*)"Rad transfer is computed",
     &		" every iradia physical timestep"
         iradia=1 ! default value
         call getin_p("iradia",iradia)
         if (is_master) write(*,*)" iradia = ",iradia
       
         if (is_master) write(*,*)"Rayleigh scattering ?"
         rayleigh=.false.
         call getin_p("rayleigh",rayleigh)
         if (is_master) write(*,*)" rayleigh = ",rayleigh

         if (is_master) write(*,*) "Use blackbody for stellar",
     & 		" spectrum ?"
         stelbbody=.false. ! default value
         call getin_p("stelbbody",stelbbody)
         if (is_master) write(*,*) " stelbbody = ",stelbbody

         if (is_master) write(*,*) "Stellar blackbody temperature ?"
         stelTbb=5800.0 ! default value
         call getin_p("stelTbb",stelTbb)
         if (is_master) write(*,*) " stelTbb = ",stelTbb

         if (is_master) write(*,*)"Output mean OLR in 1D?"
         meanOLR=.false.
         call getin_p("meanOLR",meanOLR)
         if (is_master) write(*,*)" meanOLR = ",meanOLR

         if (is_master) write(*,*)"Output spectral OLR in 3D?"
         specOLR=.false.
         call getin_p("specOLR",specOLR)
         if (is_master) write(*,*)" specOLR = ",specOLR

         if (is_master) write(*,*)"Operate in kastprof mode?"
         kastprof=.false.
         call getin_p("kastprof",kastprof)
         if (is_master) write(*,*)" kastprof = ",kastprof

         if (is_master) write(*,*)"Uniform absorption in",
     &		" radiative transfer?"
         graybody=.false.
         call getin_p("graybody",graybody)
         if (is_master) write(*,*)" graybody = ",graybody

! Slab Ocean 
         if (is_master) write(*,*) "Use slab-ocean ?"
         ok_slab_ocean=.false.         ! default value
         call getin_p("ok_slab_ocean",ok_slab_ocean)
         if (is_master) write(*,*) "ok_slab_ocean = ",ok_slab_ocean

         if (is_master) write(*,*) "Use slab-sea-ice ?"
         ok_slab_sic=.true.         ! default value
         call getin_p("ok_slab_sic",ok_slab_sic)
         if (is_master) write(*,*) "ok_slab_sic = ",ok_slab_sic

         if (is_master) write(*,*) "Use heat transport for the ocean ?"
         ok_slab_heat_transp=.true.   ! default value
         call getin_p("ok_slab_heat_transp",ok_slab_heat_transp)
         if (is_master) write(*,*) "ok_slab_heat_transp = ",
     &		ok_slab_heat_transp



! Test of incompatibility:
! if kastprof used, we must be in 1D
         if (kastprof.and.(ngrid.gt.1)) then
           if (is_master) print*,'kastprof can only be used in 1D!'
           call abort
         endif

         if (is_master) write(*,*)"Stratospheric temperature",
     &		" for kastprof mode?"
         Tstrat=167.0
         call getin_p("Tstrat",Tstrat)
         if (is_master) write(*,*)" Tstrat = ",Tstrat

         if (is_master) write(*,*)"Remove lower boundary?"
         nosurf=.false.
         call getin_p("nosurf",nosurf)
         if (is_master) write(*,*)" nosurf = ",nosurf

! Tests of incompatibility:
         if (nosurf.and.callsoil) then
           if (is_master) print*,'nosurf not compatible with soil',
     &		' scheme! ... got to make a choice!'
           call abort
         endif

         if (is_master) write(*,*)"Add an internal heat flux?",
     .             "... matters only if callsoil=F"
         intheat=0.
         call getin_p("intheat",intheat)
         if (is_master) write(*,*)" intheat = ",intheat

         if (is_master) write(*,*)"Use Newtonian cooling for",
     &		" radiative transfer?"
         newtonian=.false.
         call getin_p("newtonian",newtonian)
         if (is_master) write(*,*)" newtonian = ",newtonian

! Tests of incompatibility:
         if (newtonian.and.corrk) then
           if (is_master) print*,'newtonian not compatible with ',
     &		'correlated-k!'
           call abort
         endif
         if (newtonian.and.calladj) then
           if (is_master) print*,'newtonian not compatible with ',
     &		'adjustment!'
           call abort
         endif
         if (newtonian.and.calldifv) then
           if (is_master) print*,'newtonian not compatible with a ',
     &		'boundary layer!'
           call abort
         endif

         if (is_master) write(*,*)"Test physics timescale in 1D?"
         testradtimes=.false.
         call getin_p("testradtimes",testradtimes)
         if (is_master) write(*,*)" testradtimes = ",testradtimes

! Test of incompatibility:
! if testradtimes used, we must be in 1D
         if (testradtimes.and.(ngrid.gt.1)) then
           if (is_master) print*,'testradtimes can only be used in 1D!'
           call abort
         endif

         if (is_master) write(*,*)"Default planetary temperature?"
         tplanet=215.0
         call getin_p("tplanet",tplanet)
         if (is_master) write(*,*)" tplanet = ",tplanet

         if (is_master) write(*,*)"Which star?"
         startype=1 ! default value = Sol
         call getin_p("startype",startype)
         if (is_master) write(*,*)" startype = ",startype

         if (is_master) write(*,*)"Value of stellar flux at 1 AU?"
         Fat1AU=1356.0 ! default value = Sol today
         call getin_p("Fat1AU",Fat1AU)
         if (is_master) write(*,*)" Fat1AU = ",Fat1AU


! TRACERS:

         if (is_master) write(*,*)"Varying H2O cloud fraction?"
         CLFvarying=.false.     ! default value
         call getin_p("CLFvarying",CLFvarying)
         if (is_master) write(*,*)" CLFvarying = ",CLFvarying

         if (is_master) write(*,*)"Value of fixed H2O cloud fraction?"
         CLFfixval=1.0                ! default value
         call getin_p("CLFfixval",CLFfixval)
         if (is_master) write(*,*)" CLFfixval = ",CLFfixval

         if (is_master) write(*,*)"fixed radii for Cloud particles?"
         radfixed=.false. ! default value
         call getin_p("radfixed",radfixed)
         if (is_master) write(*,*)" radfixed = ",radfixed

         if(kastprof)then
            radfixed=.true.
         endif  

	 if (is_master) write(*,*)"Number mixing ratio of CO2 ice particles:"
         Nmix_co2=1.e6 ! default value
         call getin_p("Nmix_co2",Nmix_co2)
         if (is_master) write(*,*)" Nmix_co2 = ",Nmix_co2

!         write(*,*)"Number of radiatively active aerosols:"
!         naerkind=0. ! default value
!         call getin_p("naerkind",naerkind)
!         write(*,*)" naerkind = ",naerkind

         if (is_master) write(*,*)"Opacity of dust (if used):"
         dusttau=0. ! default value
         call getin_p("dusttau",dusttau)
         if (is_master) write(*,*)" dusttau = ",dusttau

         if (is_master) write(*,*)"Radiatively active CO2 aerosols?"
         aeroco2=.false.     ! default value
         call getin_p("aeroco2",aeroco2)
         if (is_master) write(*,*)" aeroco2 = ",aeroco2

         if (is_master) write(*,*)"Fixed CO2 aerosol distribution?"
         aerofixco2=.false.     ! default value
         call getin_p("aerofixco2",aerofixco2)
         if (is_master) write(*,*)" aerofixco2 = ",aerofixco2

         if (is_master) write(*,*)"Radiatively active water ice?"
         aeroh2o=.false.     ! default value
         call getin_p("aeroh2o",aeroh2o)
         if (is_master) write(*,*)" aeroh2o = ",aeroh2o

         if (is_master) write(*,*)"Fixed H2O aerosol distribution?"
         aerofixh2o=.false.     ! default value
         call getin_p("aerofixh2o",aerofixh2o)
         if (is_master) write(*,*)" aerofixh2o = ",aerofixh2o

         if (is_master) write(*,*)"Radiatively active sulfuric",
     &		" acid aersols?"
         aeroh2so4=.false.     ! default value
         call getin_p("aeroh2so4",aeroh2so4)
         if (is_master) write(*,*)" aeroh2so4 = ",aeroh2so4
	 
!=================================

	 if (is_master) write(*,*)"Radiatively active two-layer aersols?"
         aeroback2lay=.false.     ! default value
         call getin_p("aeroback2lay",aeroback2lay)
         if (is_master) write(*,*)" aeroback2lay = ",aeroback2lay

         if (is_master) write(*,*)"TWOLAY AEROSOL: total optical depth ",
     &              "in the tropospheric layer (visible)"
         obs_tau_col_tropo=8.D0
         call getin_p("obs_tau_col_tropo",obs_tau_col_tropo)
         if (is_master) write(*,*)" obs_tau_col_tropo = ",
     &		obs_tau_col_tropo

         if (is_master) write(*,*)"TWOLAY AEROSOL: total optical depth ",
     &              "in the stratospheric layer (visible)"
         obs_tau_col_strato=0.08D0
         call getin_p("obs_tau_col_strato",obs_tau_col_strato)
         if (is_master) write(*,*)" obs_tau_col_strato = ",
     &		obs_tau_col_strato

         if (is_master) write(*,*)"TWOLAY AEROSOL: pres_bottom_tropo?",
     &		" in pa"
         pres_bottom_tropo=66000.0
         call getin_p("pres_bottom_tropo",pres_bottom_tropo)
         if (is_master) write(*,*)" pres_bottom_tropo = ",
     &		pres_bottom_tropo

         if (is_master) write(*,*)"TWOLAY AEROSOL: pres_top_tropo?",
     &		" in pa"
         pres_top_tropo=18000.0
         call getin_p("pres_top_tropo",pres_top_tropo)
         if (is_master) write(*,*)" pres_top_tropo = ",pres_top_tropo

         if (is_master) write(*,*)"TWOLAY AEROSOL: pres_bottom_strato?",
     &		" in pa"
         pres_bottom_strato=2000.0
         call getin_p("pres_bottom_strato",pres_bottom_strato)
         if (is_master) write(*,*)" pres_bottom_strato = ",
     &		pres_bottom_strato

         if (is_master) write(*,*)"TWOLAY AEROSOL: pres_top_strato?",
     &		" in pa"
         pres_top_strato=100.0
         call getin_p("pres_top_strato",pres_top_strato)
         if (is_master) write(*,*)" pres_top_strato = ",pres_top_strato

         if (is_master) write(*,*)"TWOLAY AEROSOL: particle size",
     &		" in the tropospheric layer, in meters"
         size_tropo=2.e-6
         call getin_p("size_tropo",size_tropo)
         if (is_master) write(*,*)" size_tropo = ",size_tropo

         if (is_master) write(*,*)"TWOLAY AEROSOL: particle size",
     &		 "in the stratospheric layer, in meters"
         size_strato=1.e-7
         call getin_p("size_strato",size_strato)
         if (is_master) write(*,*)" size_strato = ",size_strato

!=================================

         if (is_master) write(*,*)"Cloud pressure level (with ",
     &		"kastprof only):"
         cloudlvl=0. ! default value
         call getin_p("cloudlvl",cloudlvl)
         if (is_master) write(*,*)" cloudlvl = ",cloudlvl

         if (is_master) write(*,*)"Is the variable gas species",
     &		" radiatively active?"
         Tstrat=167.0
         varactive=.false.
         call getin_p("varactive",varactive)
         if (is_master) write(*,*)" varactive = ",varactive

         if (is_master) write(*,*)"Is the variable gas species",
     &		" distribution set?"
         varfixed=.false.
         call getin_p("varfixed",varfixed)
         if (is_master) write(*,*)" varfixed = ",varfixed

         if (is_master) write(*,*)"What is the saturation % of",
     &		" the variable species?"
         satval=0.8
         call getin_p("satval",satval)
         if (is_master) write(*,*)" satval = ",satval


! Test of incompatibility:
! if varactive, then varfixed should be false
         if (varactive.and.varfixed) then
           if (is_master) print*,'if varactive, varfixed must be OFF!'
           stop
         endif

         if (is_master) write(*,*) "Gravitationnal sedimentation ?"
         sedimentation=.false. ! default value
         call getin_p("sedimentation",sedimentation)
         if (is_master) write(*,*) " sedimentation = ",sedimentation

         if (is_master) write(*,*) "Compute water cycle ?"
         water=.false. ! default value
         call getin_p("water",water)
         if (is_master) write(*,*) " water = ",water
         
! Test of incompatibility:
! if water is true, there should be at least a tracer
         if (water.and.(.not.tracer)) then
           if (is_master) print*,'if water is ON, tracer must be ',
     &		'ON too!'
           stop
         endif

         if (is_master) write(*,*) "Include water condensation ?"
         watercond=.false. ! default value
         call getin_p("watercond",watercond)
         if (is_master) write(*,*) " watercond = ",watercond

! Test of incompatibility:
! if watercond is used, then water should be used too
         if (watercond.and.(.not.water)) then
           if (is_master) print*,'if watercond is used, water should ',
     &		'be used too'
           stop
         endif

         if (is_master) write(*,*) "Include water precipitation ?"
         waterrain=.false. ! default value
         call getin_p("waterrain",waterrain)
         if (is_master) write(*,*) " waterrain = ",waterrain

         if (is_master) write(*,*) "Include surface hydrology ?"
         hydrology=.false. ! default value
         call getin_p("hydrology",hydrology)
         if (is_master) write(*,*) " hydrology = ",hydrology

         if (is_master) write(*,*) "Evolve surface water sources ?"
         sourceevol=.false. ! default value
         call getin_p("sourceevol",sourceevol)
         if (is_master) write(*,*) " sourceevol = ",sourceevol

         if (is_master) write(*,*) "Ice evolution timestep ?"
         icetstep=100.0 ! default value
         call getin_p("icetstep",icetstep)
         if (is_master) write(*,*) " icetstep = ",icetstep

         if (is_master) write(*,*) "Snow albedo ?"
         albedosnow=0.5         ! default value
         call getin_p("albedosnow",albedosnow)
         if (is_master) write(*,*) " albedosnow = ",albedosnow

         if (is_master) write(*,*) "Maximum ice thickness ?"
         maxicethick=2.0         ! default value
         call getin_p("maxicethick",maxicethick)
         if (is_master) write(*,*) " maxicethick = ",maxicethick

         if (is_master) write(*,*) "Freezing point of seawater ?"
         Tsaldiff=-1.8          ! default value
         call getin_p("Tsaldiff",Tsaldiff)
         if (is_master) write(*,*) " Tsaldiff = ",Tsaldiff

         if (is_master) write(*,*) "Does user want to force",
     &		" cpp and mugaz?"
         force_cpp=.false. ! default value
         call getin_p("force_cpp",force_cpp)
         if (is_master) write(*,*) " force_cpp = ",force_cpp

         if (force_cpp) then
           mugaz = -99999.
           if (is_master) PRINT *,'MEAN MOLECULAR MASS in g mol-1 ?'
           call getin_p("mugaz",mugaz)
           IF (mugaz.eq.-99999.) THEN
               if (is_master) PRINT *, "mugaz must be set if ',
     &		'force_cpp = T"
               STOP
           ELSE
               if (is_master) write(*,*) "inifis: mugaz=",mugaz
           ENDIF
           !Ehouarn: once mugaz has been set, r, the specific
           ! gas constant must be computed
           r=8.3144622/(mugaz*1.e-3)
           if (is_master) write(*,*) "inifis: r=",r
           
           cpp = -99999.
           if (is_master) PRINT *,'SPECIFIC HEAT CAPACITY in ',
     &		'J K-1 kg-1 ?'
           call getin_p("cpp",cpp)
           IF (cpp.eq.-99999.) THEN
               if (is_master) PRINT *, "cpp must be set if ',
     &		'force_cpp = T"
               STOP
           ELSE
               if (is_master) write(*,*) "inifis: cpp=",cpp
           ENDIF
!         else
!           mugaz=8.314*1000./pr
         endif
         call su_gases
         call calc_cpp_mugaz

         if (is_master) PRINT*,'------------------------------------'
         if (is_master) PRINT*
         if (is_master) PRINT*
      ELSE
         if (is_master) write(*,*)
         if (is_master) write(*,*) 'Cannot read file callphys.def.",
     &		" Is it here ?'
         stop
      ENDIF

8000  FORMAT(t5,a12,l8)
8001  FORMAT(t5,a12,i8)

      if (is_master) then
      PRINT*
      PRINT*,'inifis: daysec',daysec
      PRINT*
      PRINT*,'inifis: The radiative transfer is computed:'
      PRINT*,'           each ',iradia,' physical time-step'
      PRINT*,'        or each ',iradia*dtphys,' seconds'
      PRINT*
      end if


!-----------------------------------------------------------------------
!     Some more initialization:
!     ------------------------

      ! ALLOCATE ARRAYS IN comgeomfi_h
      IF (.not. ALLOCATED(lati)) ALLOCATE(lati(ngrid))
      IF (.not. ALLOCATED(long)) ALLOCATE(long(ngrid))
      IF (.not. ALLOCATED(area)) ALLOCATE(area(ngrid))

      CALL SCOPY(ngrid,plon,1,long,1)
      CALL SCOPY(ngrid,plat,1,lati,1)
      CALL SCOPY(ngrid,parea,1,area,1)
      totarea=SSUM(ngrid,area,1)
      call planetwide_sumval(area,totarea_planet)

      !! those are defined in comdiurn_h.F90
      IF (.not.ALLOCATED(sinlat)) ALLOCATE(sinlat(ngrid))
      IF (.not.ALLOCATED(coslat)) ALLOCATE(coslat(ngrid))
      IF (.not.ALLOCATED(sinlon)) ALLOCATE(sinlon(ngrid))
      IF (.not.ALLOCATED(coslon)) ALLOCATE(coslon(ngrid))

      DO ig=1,ngrid
         sinlat(ig)=sin(plat(ig))
         coslat(ig)=cos(plat(ig))
         sinlon(ig)=sin(plon(ig))
         coslon(ig)=cos(plon(ig))
      ENDDO

!$OMP MASTER
      pi=2.*asin(1.) ! NB: pi is a common in comcstfi.h
!$OMP END MASTER
!$OMP BARRIER

      ! allocate "comsoil_h" arrays
      call ini_comsoil_h(ngrid)
      
      END
